pub struct Font {
pub offset: Delta<i8>,
pub glyph_offset: Delta<i8>,
pub use_thin_strokes: bool,
normal: FontDescription,
bold: SecondaryFontDescription,
italic: SecondaryFontDescription,
bold_italic: SecondaryFontDescription,
size: Size,
pub builtin_box_drawing: bool,
}Expand description
Font config.
Defaults are provided at the level of this struct per platform, but not per field in this struct. It might be nice in the future to have defaults for each value independently. Alternatively, maybe erroring when the user doesn’t provide complete config is Ok.
Fields
offset: Delta<i8>Extra spacing per character.
glyph_offset: Delta<i8>Glyph offset within character cell.
use_thin_strokes: boolnormal: FontDescriptionNormal font face.
bold: SecondaryFontDescriptionBold font face.
italic: SecondaryFontDescriptionItalic font face.
bold_italic: SecondaryFontDescriptionBold italic font face.
size: SizeFont size in points.
builtin_box_drawing: boolWhether to use the built-in font for box drawing characters.
Implementations
Sourceimpl Font
impl Font
pub fn size(&self) -> FontSize
Sourcepub fn normal(&self) -> &FontDescription
pub fn normal(&self) -> &FontDescription
Get normal font description.
Sourcepub fn bold(&self) -> FontDescription
pub fn bold(&self) -> FontDescription
Get bold font description.
Sourcepub fn italic(&self) -> FontDescription
pub fn italic(&self) -> FontDescription
Get italic font description.
Sourcepub fn bold_italic(&self) -> FontDescription
pub fn bold_italic(&self) -> FontDescription
Get bold italic font description.